=== modified file 'AUTHORS'
--- AUTHORS	2014-03-01 21:15:24 +0000
+++ AUTHORS	2014-03-05 19:25:18 +0000
@@ -132,4 +132,5 @@
 * Sagar Ghuge <ghugesss@gmail.com>
 * Sushant Raikar <sushantthecoder@gmail.com>
 * Atit Anand <atit.anand.cs@gmail.com>
-* Sara Ribeiro <sara.rmgr@gmail.com>
+* Parth P. Panchal <parthpanchl@gmail.com>
+* Sara Ribeiro <sara.rmgr@gmail.com>
\ No newline at end of file

=== modified file 'CHANGELOG'
--- CHANGELOG	2014-03-01 21:15:24 +0000
+++ CHANGELOG	2014-03-05 19:25:18 +0000
@@ -18,6 +18,7 @@
     * Fix for bug #1286491 : RTM sync backend fails to load, by Pawan Hegde
     * Fix for bug #1286493 : GTG cannot connect to RTM, by Pawan Hegde
     * Fix for bug #1288011 : More intuitive title label for tasks, by Sara Ribeiro
+    * Fix for bug #316922 : Have a link to the parent(s) in the task editor, by Parth Panchal
 
 2013-11-24 Getting Things GNOME! 0.3.1
     * Fix for bug #1024473: Have 'Show Main Window' in notification area, by Antonio Roquentin

=== modified file 'GTG/gtk/editor/editor.py'
--- GTG/gtk/editor/editor.py	2013-11-25 02:37:46 +0000
+++ GTG/gtk/editor/editor.py	2014-03-05 19:25:18 +0000
@@ -68,6 +68,7 @@
         self.subtask_button.set_tooltip_text(GnomeConfig.SUBTASK_TOOLTIP)
         self.inserttag_button = self.builder.get_object("inserttag")
         self.inserttag_button.set_tooltip_text(GnomeConfig.TAG_TOOLTIP)
+        self.open_parents_button = self.builder.get_object("open_parents")
 
         # Create our dictionary and connect it
         dic = {
@@ -95,6 +96,7 @@
                 w, e, GTGCalendar.DATE_KIND_CLOSED),
             "on_insert_subtask_clicked": self.insert_subtask,
             "on_inserttag_clicked": self.inserttag_clicked,
+            "on_open_parent_clicked": self.open_parent_clicked,
             "on_move": self.on_move,
         }
         self.builder.connect_signals(dic)
@@ -359,6 +361,20 @@
                 menu.append(mi)
         if tag_count > 0:
             self.inserttag_button.set_menu(menu)
+            
+        # Refreshing the parent list in open_parent_button
+        menu = Gtk.Menu()
+        parents = self.task.get_parents()
+        if len(parents) > 0:
+            for parent in self.task.get_parents():
+                task = self.req.get_task(parent)
+                mi = Gtk.MenuItem(label = task.get_title(), use_underline=False)
+                mi.connect("activate", self.open_parent, parent)
+                mi.show()
+                menu.append(mi)
+            self.open_parents_button.set_menu(menu)
+        else:
+            self.open_parents_button.set_sensitive(False)
 
         if refreshtext:
             self.textview.modified(refresheditor=False)
@@ -503,6 +519,13 @@
     def inserttag(self, widget, tag):
         self.textview.insert_tags([tag])
         self.textview.grab_focus()
+        
+    def open_parent_clicked(self, widget):
+        self.vmanager.open_task(self.task.get_parents()[0])
+    
+    # On click handler for open_parent_button's menu items
+    def open_parent(self, widget, tid):
+        self.vmanager.open_task(tid)
 
     def save(self):
         self.task.set_title(self.textview.get_title())

=== modified file 'GTG/gtk/editor/taskeditor.ui'
--- GTG/gtk/editor/taskeditor.ui	2014-02-18 21:25:17 +0000
+++ GTG/gtk/editor/taskeditor.ui	2014-03-05 19:25:18 +0000
@@ -4,7 +4,7 @@
   <object class="GtkWindow" id="TaskEditor">
     <property name="can_focus">False</property>
     <property name="title" translatable="yes">Task</property>
-    <property name="default_width">450</property>
+    <property name="default_width">500</property>
     <property name="default_height">400</property>
     <signal name="configure-event" handler="on_move" swapped="no"/>
     <child>
@@ -93,6 +93,36 @@
               </packing>
             </child>
             <child>
+                <object class="GtkSeparatorToolItem" id="toolbutton2">
+                    <property name="visible">True</property>
+                    <property name="can_focus">False</property>
+                </object>
+                <packing>
+                    <property name="expand">False</property>
+                    <property name="homogeneous">True</property>
+                </packing>
+            </child>
+            <child>
+              <object class="GtkMenuToolButton" id="open_parents">
+                <property name="visible">True</property>
+                <property name="can_focus">False</property>
+                <property name="label" translatable="yes">Open parent task</property>
+                <property name="stock_id">gtk-go-up</property>
+                <accelerator key="p" signal="clicked" modifiers="GDK_CONTROL_MASK"/>
+                <child internal-child="accessible">
+                  <object class="AtkObject" id="open_parents-atkobject">
+                    <property name="AtkObject::accessible-name" translatable="yes">Open parent task</property>
+                    <property name="AtkObject::accessible-description" translatable="yes">Opens parent task of this task</property>
+                  </object>
+                </child>
+                <signal name="clicked" handler="on_open_parent_clicked" swapped="no"/>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="homogeneous">True</property>
+              </packing>
+            </child>
+            <child>
               <object class="GtkSeparatorToolItem" id="separator_note">
                 <property name="visible">True</property>
                 <property name="can_focus">False</property>
@@ -186,7 +216,7 @@
                     <property name="invisible_char">●</property>
                     <property name="width_chars">10</property>
                     <signal name="changed" handler="startingdate_changed" swapped="no"/>
-                    <signal name="focus-out-event" handler="startdate_focus_out"/>
+                    <signal name="focus-out-event" handler="startdate_focus_out" swapped="no"/>
                   </object>
                   <packing>
                     <property name="expand">False</property>
@@ -249,7 +279,7 @@
                     <property name="invisible_char">●</property>
                     <property name="width_chars">10</property>
                     <signal name="changed" handler="duedate_changed" swapped="no"/>
-                    <signal name="focus-out-event" handler="duedate_focus_out"/>
+                    <signal name="focus-out-event" handler="duedate_focus_out" swapped="no"/>
                   </object>
                   <packing>
                     <property name="expand">False</property>
@@ -312,7 +342,7 @@
                     <property name="invisible_char">●</property>
                     <property name="width_chars">10</property>
                     <signal name="changed" handler="closeddate_changed" swapped="no"/>
-                    <signal name="focus-out-event" handler="closeddate_focus_out"/>
+                    <signal name="focus-out-event" handler="closeddate_focus_out" swapped="no"/>
                   </object>
                   <packing>
                     <property name="expand">False</property>

